@@ -6,38 +6,22 @@ import shutil
 import subprocess
 import sys
 import tempfile
-from collections import defaultdict
 from importlib import import_module
 from pathlib import Path
 from textwrap import dedent
-from typing import DefaultDict, Dict, Iterator, List, Optional, Set, Tuple
+from typing import Dict, Iterator, List, Optional, Set, Tuple
 
 from pkg_resources import parse_version
 
 from nbqa import config_parser, replace_source, save_source
-from nbqa.cmdline import BOLD, RESET, CLIArgs
-from nbqa.config.config import Configs
+from nbqa.cmdline import CLIArgs
+from nbqa.config.config import CONFIG_FILES, Configs
 from nbqa.find_root import find_project_root
 from nbqa.notebook_info import NotebookInfo
 from nbqa.optional import metadata
 from nbqa.output_parser import map_python_line_to_nb_lines
+from nbqa.text import BOLD, RESET
 
-CONFIG_FILES: DefaultDict[str, List[str]] = defaultdict(
-    lambda: ["setup.cfg", "tox.ini", "pyproject.toml"]
-)
-CONFIG_FILES["black"] = ["pyproject.toml"]
-CONFIG_FILES["flake8"] = ["setup.cfg", "tox.ini", ".flake8"]
-CONFIG_FILES["pyupgrade"] = []
-CONFIG_FILES["mypy"] = ["mypy.ini", ".mypy.ini", "setup.cfg"]
-CONFIG_FILES["doctest"] = []
-CONFIG_FILES["isort"] = [
-    ".isort.cfg",
-    "pyproject.toml",
-    "setup.cfg",
-    "tox.ini",
-    ".editorconfig",
-]
-CONFIG_FILES["pylint"] = ["pylintrc", ".pylintrc", "pyproject.toml", "setup.cfg"]
 BASE_ERROR_MESSAGE = dedent(
     f"""\
     {BOLD}{{}}
@@ -56,6 +40,12 @@ EXCLUDES = (
 )
 
 
+REPLACE_FUNCTION = {
+    True: replace_source.diff,
+    False: replace_source.mutate,
+}
+
+
 class UnsupportedPackageVersionError(Exception):
     """Raise if installed module is older than minimum required version."""
 
@@ -331,10 +321,8 @@ def _get_arg(
     'tmpdir/my_notebook.py'
     """
     if Path(root_dir).is_dir():
-        arg = Path(tmpdirname) / Path(root_dir).resolve().relative_to(project_root)
-    else:
-        arg = nb_to_py_mapping[Path(root_dir)]
-    return arg
+        return Path(tmpdirname) / Path(root_dir).resolve().relative_to(project_root)
+    return nb_to_py_mapping[Path(root_dir)]
 
 
 def _get_all_args(
@@ -601,21 +589,27 @@ def _run_on_one_root_dir(
                 sys.stderr.write(BASE_ERROR_MESSAGE.format(msg))
 
             if mutated:
-                if not configs.nbqa_mutate:
+                if not configs.nbqa_mutate and not configs.nbqa_diff:
                     # pylint: disable=C0301
                     msg = dedent(
                         f"""\
                         {BOLD}Mutation detected, will not reformat! Please use the `--nbqa-mutate` flag, e.g.:{RESET}
 
                             nbqa {cli_args.command} notebook.ipynb --nbqa-mutate
+
+                        or, to only preview changes, use the `--nbqa-diff` flag, e.g.:
+
+                            nbqa {cli_args.command} notebook.ipynb --nbqa-diff
                         """
                     )
                     # pylint: enable=C0301
                     raise SystemExit(msg)
 
                 try:
-                    replace_source.main(
-                        temp_python_file, notebook, nb_info_mapping[notebook]
+                    REPLACE_FUNCTION[configs.nbqa_diff](
+                        temp_python_file,
+                        notebook,
+                        nb_info_mapping[notebook],
                     )
                 except Exception as exc:
                     raise RuntimeError(
@@ -624,6 +618,13 @@ def _run_on_one_root_dir(
                         )
                     ) from exc
 
+        if configs.nbqa_diff:
+            if mutated:
+                sys.stdout.write(
+                    "To apply these changes use `--nbqa-mutate` instead of `--nbqa-diff`\n"
+                )
+            return 0
+
         sys.stdout.write(out)
         sys.stderr.write(err)
 
@@ -676,6 +677,7 @@ def main(argv: Optional[List[str]] = None) -> None:
     _check_command_is_installed(cli_args.command)
     project_root: Path = find_project_root(tuple(cli_args.root_dirs))
     configs: Configs = _get_configs(cli_args, project_root)
+    configs.validate()
 
     output_code = _run_on_one_root_dir(cli_args, configs, project_root)
 
