@@ -157,7 +157,7 @@ def mutate(python_file: "Path", notebook: "Path", notebook_info: NotebookInfo) -
     notebook_info
         Information about notebook cells used for processing
     """
-    notebook_json = json.loads(notebook.read_text())
+    notebook_json = json.loads(notebook.read_text(encoding="utf-8"))
 
     pycells = _get_pycells(python_file)
     for code_cell_number, cell in enumerate(
@@ -167,7 +167,9 @@ def mutate(python_file: "Path", notebook: "Path", notebook_info: NotebookInfo) -
             continue
         cell["source"] = _get_new_source(code_cell_number, notebook_info, next(pycells))
 
-    notebook.write_text(f"{json.dumps(notebook_json, indent=1, ensure_ascii=False)}\n")
+    notebook.write_text(
+        f"{json.dumps(notebook_json, indent=1, ensure_ascii=False)}\n", encoding="utf-8"
+    )
 
 
 def _print_diff(code_cell_number: int, cell_diff: Iterator[str]) -> None:
@@ -211,7 +213,7 @@ def diff(python_file: "Path", notebook: "Path", notebook_info: NotebookInfo) ->
     notebook_info
         Information about notebook cells used for processing
     """
-    notebook_json = json.loads(notebook.read_text())
+    notebook_json = json.loads(notebook.read_text(encoding="utf-8"))
 
     pycells = _get_pycells(python_file)
 
